XIncludeFile ".\include\Chipmunk4PB_v0.1.pbi"

Global *space.cpSpace
Global *staticBody.cpBody
Global ticks

Procedure DrawPolyShape(*poly.cpPolyShape)
  Protected *verts.cpVect=*poly\verts
  Protected last.cpVect
  Protected v.cpVect
  Protected first.cpVect

  
  ;*last=*verts+SizeOf(cpVect)*(*poly\numVerts-1)
  cpvrotate(v, *poly\verts, *poly\shape\body\rot)
  cpvadd(v, v, *poly\shape\body\p)
  cpv(last, v\x, v\y)
  
  For i=0 To *poly\numVerts-1
    cpvrotate(v, *verts, *poly\shape\body\rot)
    cpvadd(v, v, *poly\shape\body\p)
    LineXY(last\x, last\y, v\x, v\y, RGB(0, 0, 0))
    cpv(last, v\x,v\y)
    *verts+SizeOf(cpVect)
  Next
 ; Circle(*poly\shape\body\p\x, *poly\shape\body\p\y, 2, RGB(0, 0, 255))
EndProcedure
Procedure DrawCircleShape(*circle.cpCircleShape)
  Protected x=*circle\tc\x
  Protected y=*circle\tc\y
  Protected r.f=*circle\r
  Protected a.f=*circle\shape\body\a
  Circle(x, y, r)
  LineXY(x, y, x+Cos(a)*r, y+Sin(a)*r)
EndProcedure
Procedure DrawSegmentShape(*seg.cpSegmentShape)
  Protected a.cpVect
  Protected b.cpVect
  
  cpvrotate(@a, *seg\a, *seg\shape\body\rot)
  cpvrotate(@b, *seg\b, *seg\shape\body\rot)
  cpvadd(@a, a, *seg\shape\body\p)
  cpvadd(@b, b, *seg\shape\body\p)
  
  LineXY(a\x, a\y, b\x, b\y, RGB(0, 0, 0))
EndProcedure
ProcedureC DrawShape(*shape.cpShape, *datas)
  Select *shape\klass\type
    Case #CP_CIRCLE_SHAPE
      DrawCircleShape(*shape)
    Case #CP_SEGMENT_SHAPE
      DrawSegmentShape(*shape)
    Case #CP_POLY_SHAPE
      DrawPolyShape(*shape)
  EndSelect
EndProcedure
ProcedureC DrawCollisions(*arbiter.cpArbiter, *datas)
  Protected i
  For i=0 To *arbiter\numContacts-1
    *contacts.cpContact=*arbiter\contacts+SizeOf(cpContact)*i
    Circle(*contacts\p\x, *contacts\p\y, 2, #Red)
  Next
EndProcedure
ProcedureC DetectCollisions(*a.cpShape, *b.cpShape, *contacts.cpContact, numContacts.i, normal_coef.f, *datas)
  Protected i
  For i=0 To numContacts-1
 ;   Debug "Collision n"+Str(numContacts)+" at "+cpvstr(*contacts\p)+". ("+Str(*a\collision_type)+" - "+Str(*b\collision_type)+") "+Str(*datas)
    *contacts+SizeOf(cpContact)
  Next
  ProcedureReturn 1
EndProcedure

Procedure InitObjects()
  Protected *shape.cpShape
  Protected *body.cpBody
  Protected i, j
  
  cpInitChipmunk()
  cpResetShapeIdCounter()
  
  ;{/// PHYSIC ENVIRONMENT
  *staticBody=cpBodyNew(#INFINITY, #INFINITY)
  
  *space=cpSpaceNew()
  cpv(*space\gravity, 0, 100)
  cpSpaceResizeStaticHash(*space, 20.0, 999)
  ;}
  
  ;{/// SCREEN BORDERS
  Dim vecBorderA.cpVect(3)
  Dim vecBorderB.cpVect(3)
  cpv(vecBorderA(0), 0, 0)
  cpv(vecBorderB(0), 0, 480)
  cpv(vecBorderA(1), 639, 0)
  cpv(vecBorderB(1), 639, 480)
  cpv(vecBorderA(2), 0, 479)
  cpv(vecBorderB(2), 640, 479)
  For i=0 To 2
    *shape=cpSegmentShapeNew(*staticBody, vecBorderA(i), vecBorderB(i), 0.0)
    *shape\e=1.0
    *shape\u=1.0
    cpSpaceAddStaticShape(*space, *shape)
  Next
  ;}
  
  ;{/// STAIRS
  Protected vecStairA.cpvect
  Protected vecStairB.cpvect
  Protected vecStairC.cpvect
  For i=0 To 50
    j=i+1
    cpv(vecStairA, i*10, i*10)
    cpv(vecStairB, j*10, i*10)
    cpv(vecStairC, j*10, j*10)
    
    *shape=cpSegmentShapeNew(*staticBody, vecStairA, vecStairB, 0.0)
    *shape\e=1.0
    *shape\u=1.0
    cpSpaceAddStaticShape(*space, *shape)
    
    *shape=cpSegmentShapeNew(*staticBody, vecStairB, vecStairC, 0.0)
    *shape\e=1.0
    *shape\u=1.0
    cpSpaceAddStaticShape(*space, *shape)
  Next
  ;}
  
  ;{/// FALLING BOX
  Dim vecBox.cpVect(4)
  cpv(vecBox(0), -15, -15)
  cpv(vecBox(1), -15, 15)
  cpv(vecBox(2), 15, 15)
  cpv(vecBox(3), 15, -15)

  *body=cpBodyNew(1.0, cpMomentForPoly(1.0, ArraySize(vecBox()), @vecBox(), cpvzero) )
  cpv(*body\p, 20, -20)
  cpSpaceAddBody(*space, *body)
  
  *shape=cpPolyShapeNew(*body, ArraySize(vecBox()), @vecBox(), cpvzero)
  *shape\e=0.0
  *shape\u=1.5
  *shape\collision_type=1
  cpSpaceAddShape(*space, *shape)
  
  *body=cpBodyNew(0.2, cpMomentForPoly(1.0, ArraySize(vecBox()), @vecBox(), cpvzero) )
  cpv(*body\p, 40, -20)
  cpSpaceAddBody(*space, *body)
  
  Protected *datas=0

  
EndProcedure
Procedure MoveObjects()
  ticks+1
  Protected steps.f=2.0
  Protected dt.f=1.0/60.0/steps
  Protected i
  For i=0 To steps
    cpSpaceStep(*space, dt)
  Next
EndProcedure
Procedure DrawObjects()
  Protected *datas=#Null
  ClearScreen(RGB(255, 255, 255))
  StartDrawing(ScreenOutput())
  DrawingMode(#PB_2DDrawing_Outlined)
  cpSpaceHashEach(*space\activeShapes, @DrawShape(), *datas)
  cpSpaceHashEach(*space\staticShapes, @DrawShape(), *datas)
  DrawingMode(#PB_2DDrawing_Default)
  cpArrayEach(*space\arbiters, @DrawCollisions(), param)
  StopDrawing()
  FlipBuffers()   
EndProcedure
Procedure FreeObjects()
  cpSpaceFreeChildren(*space)
  cpSpaceFree(*space)
  cpBodyFree(*staticBody)
EndProcedure

InitSprite()
InitKeyboard()
InitObjects()

OpenWindow(100, 0, 0, 640, 480, "Test : Chipmunk4PB Wrapper 0.1 - STAIRS", #PB_Window_ScreenCentered | #PB_Window_SystemMenu)
OpenWindowedScreen(WindowID(100), 0, 0, 640, 480, 0, 0, 0)
Repeat
  DrawObjects()
  MoveObjects()
  ExamineKeyboard()
Until KeyboardPushed(#PB_Key_Escape) Or WaitWindowEvent(10)=#PB_Event_CloseWindow
FreeObjects()
End









; IDE Options = PureBasic 4.51 (Windows - x86)
; CursorPosition = 149
; FirstLine = 108
; Folding = ---
; EnableThread
; CurrentDirectory = D:\Documents and Settings\eddy.eded.000\Bureau\zzzzzzz\
; CompileSourceDirectory
; EnableCompileCount = 710
; EnableBuildCount = 0