#INFINITY = 1e1000
Global GRABABLE_MASK_BIT = 1<<31

;- MACROs
Macro cpFloat: d : EndMacro
Macro cpBool : i : EndMacro
Macro cpHashValue : i : EndMacro
Macro cpConstraintClass: i : EndMacro
Macro cpContactBufferHeader: i : EndMacro
Macro cpDampedSpring: i : EndMacro
Macro cpGearJoint: i : EndMacro
Macro cpRotaryLimitJoint: i : EndMacro
Macro cpSimpleMotor: i : EndMacro
;Macro cpSlideJoint: i : EndMacro

Macro cpShapeType : l : EndMacro
Enumeration
  #CP_CIRCLE_SHAPE
  #CP_SEGMENT_SHAPE
  #CP_POLY_SHAPE
  #CP_NUM_SHAPES
EndEnumeration

Macro cpJointType : l : EndMacro
Enumeration 
  #CP_PIN_JOINT
  #CP_PIVOT_JOINT
  #CP_SLIDE_JOINT
  #CP_GROOVE_JOINT
EndEnumeration


;- STRUCTUREs
Structure  cpVect
	x.cpFloat
	y.cpFloat
EndStructure

Structure cpConstraint
	*klass.cpConstraintClass
	*a.cpBody
	*b.cpBody
	maxForce.cpFloat
	biasCoef.cpFloat
	maxBias.cpFloat
	*Data
EndStructure

Structure cpCollisionHandler
	a.i
	b.i
	*begin
	*preSolve
	*postSolve
	*separate
	*Data
EndStructure

Structure cpComponentNode
	*parent.cpBody
	*Next.cpBody
	rank.i
	idleTime.cpFloat
EndStructure

Structure  cpBody
	*velocity_func.i
	*position_func.i
	m.cpFloat
	m_inv.cpFloat
	i.cpFloat
	i_inv.cpFloat
	p.cpVect
	v.cpVect
	f.cpVect
	a.cpFloat
	w.cpFloat
	t.cpFloat
	rot.cpVect
	*data.cpDataPointer
	v_limit.cpFloat
	w_limit.cpFloat
	v_bias.cpVect
	w_bias.cpFloat
	*space.cpSpace
	*shapesList.cpShape
	node.cpComponentNode
EndStructure

Structure  cpSpace
	iterations.i
	elasticIterations.i
	gravity.cpVect
	damping.d
	idleSpeedThreshold.d
	sleepTimeThreshold.d
	locked.cpBool
	stamp.i
	*staticShapes.cpSpaceHash
	*activeShapes.cpSpaceHash
	*bodies.cpArray
	*sleepingComponents.cpArray
	*arbiters.cpArray
	*pooledArbiters.cpArray
	*contactBuffersHead.cpContactBufferHeader
	*contactBuffersTail.cpContactBufferHeader
	*allocatedBuffers.cpArray
	*contactSet.cpHashSet
	*constraints.cpArray
	*collFuncSet.cpHashSet
	defaultHandler.cpCollisionHandler
	*postStepCallbacks.cpHashSet
	staticBody.cpBody
EndStructure

Structure  cpArbiter
	numContacts.i
	*contacts.cpContact
	*private_a.cpShape
	*private_b.cpShape
	e.d
	u.d
	surface_vr.cpVect
	stamp.i
	*handler.cpCollisionHandler
	swappedColl.cpBool
	state.i
EndStructure

Structure  cpSlideJoint
	constraint.cpConstraint
	anchr1.cpVect
	anchr2.cpVect
	min.cpFloat
	max.cpFloat
	r1.cpVect
	r2.cpVect
	n.cpVect
	nMass.cpFloat
	jnAcc.cpFloat
	jnMax.cpFloat
	bias.cpFloat
EndStructure

Structure  cpRatchetJoint
	constraint.cpConstraint
	angle.cpFloat
	phase.cpFloat
	rtachet.cpFloat
	iSum.cpFloat
	bias.cpFloat
	jAcc.cpFloat
	jMax.cpFloat
EndStructure

Structure  cpPivotJoint
	constraint.cpConstraint
	anchr1.cpVect
	anchr2.cpVect
	r1.cpVect
	r2.cpVect
	k1.cpVect
	k2.cpVect
	jAcc.cpVect
	lMaxLen.cpFloat
	bias.cpVect
EndStructure

Structure  cpArray
	num.i
	max.i
	*arr._voidPOINTER
EndStructure

Structure  cpContact
	p.cpVect
	n.cpVect
	dist.cpFloat
	r1.cpVect
	r2.cpVect
	nMass.cpFloat
	tMass.cpFloat
	bounce.cpFloat
	jnAcc.cpFloat
	jtAcc.cpFloat
	jBias.cpFloat
	bias.cpFloat
	hash.cpHashValue
EndStructure

Structure  cpPolyShapeAxis
	n.cpVect
	d.cpFloat
EndStructure

Structure  cpDampedRotarySpring
	constraint.cpConstraint
	restAngle.cpFloat
	stiffness.cpFloat
	damping.cpFloat
	*springTorqueFunc
	dt.cpFloat
	target_wrn.cpFloat
	iSum.cpFloat
EndStructure

Structure  cpHandle
	*obj._voidPOINTER
	retain.i
	stamp.i
EndStructure

Structure  cpGrooveJoint
	constraint.cpConstraint
	grv_n.cpVect
	grv_a.cpVect
	grv_b.cpVect
	anchr2.cpVect
	grv_tn.cpVect
	clamp.cpFloat
	r1.cpVect
	r2.cpVect
	k1.cpVect
	k2.cpVect
	jAcc.cpVect
	jMaxLen.cpFloat
	bias.cpVect
EndStructure

Structure cpSegmentQueryInfo
	*shape.cpShape
	t.cpFloat
	n.cpVect
EndStructure

Structure cpBB
	l.cpFloat
	b.cpFloat
	r.cpFloat
	t.cpFloat
EndStructure

Structure cpShape
	*klass.cpShapeClass
	*body.cpBody
	bb.cpBB
	sensor.cpBool
	e.cpFloat
	u.cpFloat
	surface_v.cpVect
	*datas
	collision_type.i
	group.i
	layers.i
	*Next.cpShape
	hashid.cpHashValue
EndStructure
	
Structure cpCircleShape
	shape.cpShape
	c.cpVect
	r.cpFloat
	tc.cpVect
EndStructure
Structure cpSegmentShape
	shape.cpShape
	a.cpVect
	b.cpVect
	n.cpVect
	r.cpFloat
	ta.cpVect 
	tb.cpVect
	tn.cpVect
EndStructure

Structure cpPolyShape
	shape.cpShape
	numVerts.l
	*verts.cpVect
	*axes.cpPolyShapeAxis
	*tVerts.cpVect
	*tAxes.cpPolyShapeAxis
EndStructure

Structure cpHashSetBin
	*elt
	hash.i
	*next.cpHashSetBin
EndStructure

Structure cpHashSet
	entries.i
	size.i
	*eql.cpHashSetEqlFunc
	*trans.cpHashSetTransFunc
	*default_value.i
	*table.i
	*pooledBins.i
	*allocatedBuffers.cpArray
EndStructure

Structure cpSpaceHashBin
	*handle.cpHandle
	*next.cpSpaceHashBin
EndStructure

Structure cpSpaceHash
	numcells.i
	celldim.cpFloat
	*bbfunc.i
	*handleSet.cpHashSet
	*pooledHandles.cpArray
	*table.cpSpaceHashBin
	*pooledBins.cpSpaceHashBin
	*allocatedBuffers.cpArray
	stamp.i
EndStructure

Structure cpShapeClass
	type.cpShapeType
	*cacheData.cacheData_Func
	*destroy.destroy_Func
	*pointQuery.pointQuery_Func
	*segmentQuery.i
EndStructure

Structure cpJointClass
	type.cpJointType
	*preStep.preStep_Func
	*applyImpulse.applyImpulse_Func
EndStructure

Structure cpPinJoint
	constraint.cpConstraint
	anchr1.cpVect
	anchr2.cpVect
	dist.cpFloat
	r1.cpVect: 
	r2.cpVect
	n.cpVect
	nMass.cpFloat
	jnAcc.cpFloat
	jnMax.cpFloat
	bias.cpFloat
EndStructure

Structure cpCollPairFunc
	a.i
	b.i
	*func.cpCollFunc
	*datas
EndStructure

Global cpvzero.cpvect

;- Chipmunk Calls
ImportC ".\Lib\Chipmunk4PB_v0.1.lib"
 cpvstr.c(*par1.cpVect) As "?cpvstr_@@YAPADAAUcpVect@@@Z"
 cpAreaForCircle.d(par1.d, par2.d) As "?cpAreaForCircle@@YANNN@Z"
 cpAreaForPoly.d(par1.i, *par2.cpVect) As "?cpAreaForPoly@@YANHPBUcpVect@@@Z"
 cpAreaForSegment.d(*par1.cpVect, *par2.cpVect, par3.d) As "?cpAreaForSegment_@@YANAAUcpVect@@0N@Z"
 cpBodyKineticEnergy.d(*par1.cpBody) As "?cpBodyKineticEnergy@@YANPBUcpBody@@@Z"
 cpCircleShapeGetRadius.d(*par1.cpShape) As "?cpCircleShapeGetRadius@@YANPAUcpShape@@@Z"
 cpContactsEstimateCrushingImpulse.d(*par1.cpContact, par2.i) As "?cpContactsEstimateCrushingImpulse@@YANPAUcpContact@@H@Z"
 cpMomentForBox.d(par1.d, par2.d, par3.d) As "?cpMomentForBox@@YANNNN@Z"
 cpMomentForCircle.d(par1.d, par2.d, par3.d, *par4.cpVect) As "?cpMomentForCircle_@@YANNNNAAUcpVect@@@Z"
 cpMomentForSegment.d(par1.d, *par2.cpVect, *par3.cpVect) As "?cpMomentForSegment_@@YANNAAUcpVect@@0@Z"
 cpMomentForPoly.d(par1.d, par2.i, *par3.cpVect, *par4.cpVect) As "?cpMomentForPoly_@@YANNHPBUcpVect@@AAU1@@Z"
 cpPolyShapeValueOnAxis.d(*par1.cpPolyShape, *par2.cpVect, par3.d) As "?cpPolyShapeValueOnAxis_@@YANPBUcpPolyShape@@AAUcpVect@@N@Z"
 cpSegmentQueryHitDist.d(*par1.cpVect, *par2.cpVect, *par3.cpSegmentQueryInfo) As "?cpSegmentQueryHitDist_@@YANAAUcpVect@@0AAUcpSegmentQueryInfo@@@Z"
 cpSegmentShapeGetRadius.d(*par1.cpShape) As "?cpSegmentShapeGetRadius@@YANPAUcpShape@@@Z"
 cpfabs.d(par1.d) As "?cpfabs@@YANN@Z"
 cpfclamp.d(par1.d, par2.d, par3.d) As "?cpfclamp@@YANNNN@Z"
 cpfmax.d(par1.d, par2.d) As "?cpfmax@@YANNN@Z"
 cpfmin.d(par1.d, par2.d) As "?cpfmin@@YANNN@Z"
 cpvcross.d(*par1.cpVect, *par2.cpVect) As "?cpvcross_@@YANAAUcpVect@@0@Z"
 cpvdist.d(*par1.cpVect, *par2.cpVect) As "?cpvdist_@@YANAAUcpVect@@0@Z"
 cpvdistsq.d(*par1.cpVect, *par2.cpVect) As "?cpvdistsq_@@YANAAUcpVect@@0@Z"
 cpvdot.d(*par1.cpVect, *par2.cpVect) As "?cpvdot_@@YANAAUcpVect@@0@Z"
 cpvlength.d(*par1.cpVect) As "?cpvlength_@@YANAAUcpVect@@@Z"
 cpvlengthsq.d(*par1.cpVect) As "?cpvlengthsq_@@YANAAUcpVect@@@Z"
 cpvtoangle.d(*par1.cpVect) As "?cpvtoangle_@@YANAAUcpVect@@@Z"
 cpArrayContains.i(*par1.cpArray, par2.i) As "?cpArrayContains@@YAHPAUcpArray@@PAX@Z"
 cpBBcontainsBB.i(*par1.cpBB, *par2.cpBB) As "?cpBBcontainsBB_@@YAHAAUcpBB@@0@Z"
 cpBBcontainsVect.i(*par1.cpBB, *par2.cpVect) As "?cpBBcontainsVect_@@YAHAAUcpBB@@AAUcpVect@@@Z"
 cpBBintersects.i(*par1.cpBB, *par2.cpBB) As "?cpBBintersects_@@YAHAAUcpBB@@0@Z"
 cpBodyIsRogue.i(*par1.cpBody) As "?cpBodyIsRogue@@YAHPBUcpBody@@@Z"
 cpBodyIsSleeping.i(*par1.cpBody) As "?cpBodyIsSleeping@@YAHPBUcpBody@@@Z"
 cpBodyIsStatic.i(*par1.cpBody) As "?cpBodyIsStatic@@YAHPBUcpBody@@@Z"
 cpCircleShapePointQuery.i(*par1.cpShape, *par2.cpVect) As "?cpCircleShapePointQuery_@@YAHPAUcpShape@@AAUcpVect@@@Z"
 cpCollideShapes.i(*par1.cpShape, *par2.cpShape, *par3.cpContact) As "?cpCollideShapes@@YAHPBUcpShape@@0PAUcpContact@@@Z"
 cpPolyShapeContainsVertPartial.i(*par1.cpPolyShape, *par2.cpVect, *par3.cpVect) As "?cpPolyShapeContainsVertPartial_@@YAHPBUcpPolyShape@@AAUcpVect@@1@Z"
 cpPolyShapeContainsVert.i(*par1.cpPolyShape, *par2.cpVect) As "?cpPolyShapeContainsVert_@@YAHPBUcpPolyShape@@AAUcpVect@@@Z"
 cpPolyShapeGetNumVerts.i(*par1.cpShape) As "?cpPolyShapeGetNumVerts@@YAHPAUcpShape@@@Z"
 cpPolyShapePointQuery.i(*par1.cpShape, *par2.cpVect) As "?cpPolyShapePointQuery_@@YAHPAUcpShape@@AAUcpVect@@@Z"
 cpPolyValidate.i(*par1.cpVect, par2.i) As "?cpPolyValidate@@YAHPBUcpVect@@H@Z"
 cpSpaceHashPointQuery(*par1.cpSpaceHash, *par2.cpVect, *func3, par4.i, par5.i, par6.i) As "?cpSpaceHashPointQuery_@@YAXPAUcpSpaceHash@@AAUcpVect@@P6AXPAX22@Z2@Z"
 cpSegmentShapePointQuery.i(*par1.cpShape, *par2.cpVect) As "?cpSegmentShapePointQuery_@@YAHPAUcpShape@@AAUcpVect@@@Z"
 cpShapeSegmentQuery.i(*par1.cpShape, *par2.cpVect, *par3.cpVect, *par4.cpSegmentQueryInfo) As "?cpShapeSegmentQuery_@@YAHPAUcpShape@@AAUcpVect@@1PAUcpSegmentQueryInfo@@@Z"
 cpSpaceShapeQuery.i(*par1.cpSpace, *par2.cpShape, *func3, par4.i, par5.i, par6.i) As "?cpSpaceShapeQuery@@YAHPAUcpSpace@@PAUcpShape@@P6AX1PAUcpContactPointSet@@PAX@Z3@Z"
 cpveql.i(*par1.cpVect, *par2.cpVect) As "?cpveql_@@YAHAAUcpVect@@0@Z"
 cpvnear.i(*par1.cpVect, *par2.cpVect, par3.d) As "?cpvnear_@@YAHAAUcpVect@@0N@Z"
 cpArbiterAlloc.i() As "?cpArbiterAlloc@@YAPAUcpArbiter@@XZ"
 cpArbiterInit.i(*par1.cpArbiter, *par2.cpShape, *par3.cpShape) As "?cpArbiterInit@@YAPAUcpArbiter@@PAU1@PAUcpShape@@1@Z"
 cpArbiterNew.i(*par1.cpShape, *par2.cpShape) As "?cpArbiterNew@@YAPAUcpArbiter@@PAUcpShape@@0@Z"
 cpArrayAlloc.i() As "?cpArrayAlloc@@YAPAUcpArray@@XZ"
 cpArrayInit.i(*par1.cpArray, par2.i) As "?cpArrayInit@@YAPAUcpArray@@PAU1@H@Z"
 cpArrayNew.i(par1.i) As "?cpArrayNew@@YAPAUcpArray@@H@Z"
 cpBodyAlloc.i() As "?cpBodyAlloc@@YAPAUcpBody@@XZ"
 cpBodyInit.i(*par1.cpBody, par2.d, par3.d) As "?cpBodyInit@@YAPAUcpBody@@PAU1@NN@Z"
 cpBodyInitStatic.i(*par1.cpBody) As "?cpBodyInitStatic@@YAPAUcpBody@@PAU1@@Z"
 cpBodyNew.i(par1.d, par2.d) As "?cpBodyNew@@YAPAUcpBody@@NN@Z"
 cpBodyNewStatic.i() As "?cpBodyNewStatic@@YAPAUcpBody@@XZ"
 cpSpaceAddBody.i(*par1.cpSpace, *par2.cpBody) As "?cpSpaceAddBody@@YAPAUcpBody@@PAUcpSpace@@PAU1@@Z"
 cpCircleShapeAlloc.i() As "?cpCircleShapeAlloc@@YAPAUcpCircleShape@@XZ"
 cpCircleShapeInit.i(*par1.cpCircleShape, *par2.cpBody, par3.d, *par4.cpVect) As "?cpCircleShapeInit_@@YAPAUcpCircleShape@@PAU1@PAUcpBody@@NAAUcpVect@@@Z"
 cpDampedRotarySpringNew.i(*par1.cpBody, *par2.cpBody, par3.d, par4.d, par5.d) As "?cpDampedRotarySpringNew@@YAPAUcpConstraint@@PAUcpBody@@0NNN@Z"
 cpDampedSpringNew.i(*par1.cpBody, *par2.cpBody, *par3.cpVect, *par4.cpVect, par5.d, par6.d, par7.d) As "?cpDampedSpringNew_@@YAPAUcpConstraint@@PAUcpBody@@0AAUcpVect@@1NNN@Z"
 cpGearJointNew.i(*par1.cpBody, *par2.cpBody, par3.d, par4.d) As "?cpGearJointNew@@YAPAUcpConstraint@@PAUcpBody@@0NN@Z"
 cpGrooveJointNew.i(*par1.cpBody, *par2.cpBody, *par3.cpVect, *par4.cpVect, *par5.cpVect) As "?cpGrooveJointNew_@@YAPAUcpConstraint@@PAUcpBody@@0AAUcpVect@@11@Z"
 cpPinJointNew.i(*par1.cpBody, *par2.cpBody, *par3.cpVect, *par4.cpVect) As "?cpPinJointNew_@@YAPAUcpConstraint@@PAUcpBody@@0AAUcpVect@@1@Z"
 cpPivotJointNew2.i(*par1.cpBody, *par2.cpBody, *par3.cpVect, *par4.cpVect) As "?cpPivotJointNew2_@@YAPAUcpConstraint@@PAUcpBody@@0AAUcpVect@@1@Z"
 cpPivotJointNew.i(*par1.cpBody, *par2.cpBody, *par3.cpVect) As "?cpPivotJointNew_@@YAPAUcpConstraint@@PAUcpBody@@0AAUcpVect@@@Z"
 cpRatchetJointNew.i(*par1.cpBody, *par2.cpBody, par3.d, par4.d) As "?cpRatchetJointNew@@YAPAUcpConstraint@@PAUcpBody@@0NN@Z"
 cpRotaryLimitJointNew.i(*par1.cpBody, *par2.cpBody, par3.d, par4.d) As "?cpRotaryLimitJointNew@@YAPAUcpConstraint@@PAUcpBody@@0NN@Z"
 cpSimpleMotorNew.i(*par1.cpBody, *par2.cpBody, par3.d) As "?cpSimpleMotorNew@@YAPAUcpConstraint@@PAUcpBody@@0N@Z"
 cpSlideJointNew.i(*par1.cpBody, *par2.cpBody, *par3.cpVect, *par4.cpVect, par5.d, par6.d) As "?cpSlideJointNew_@@YAPAUcpConstraint@@PAUcpBody@@0AAUcpVect@@1NN@Z"
 cpSpaceAddConstraint.i(*par1.cpSpace, par2.i) As "?cpSpaceAddConstraint@@YAPAUcpConstraint@@PAUcpSpace@@PAU1@@Z"
 cpDampedRotarySpringGetClass.i() As "?cpDampedRotarySpringGetClass@@YAPBUcpConstraintClass@@XZ"
 cpDampedSpringGetClass.i() As "?cpDampedSpringGetClass@@YAPBUcpConstraintClass@@XZ"
 cpGearJointGetClass.i() As "?cpGearJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpGrooveJointGetClass.i() As "?cpGrooveJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpPinJointGetClass.i() As "?cpPinJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpPivotJointGetClass.i() As "?cpPivotJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpRatchetJointGetClass.i() As "?cpRatchetJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpRotaryLimitJointGetClass.i() As "?cpRotaryLimitJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpSimpleMotorGetClass.i() As "?cpSimpleMotorGetClass@@YAPBUcpConstraintClass@@XZ"
 cpSlideJointGetClass.i() As "?cpSlideJointGetClass@@YAPBUcpConstraintClass@@XZ"
 cpContactBufferGetArray.i(*par1.cpSpace) As "?cpContactBufferGetArray@@YAPAUcpContact@@PAUcpSpace@@@Z"
 cpContactInit.i(*par1.cpContact, *par2.cpVect, *par3.cpVect, par4.d, par5.i) As "?cpContactInit_@@YAPAUcpContact@@PAU1@AAUcpVect@@1NI@Z"
 cpContactBufferHeaderInit.i(*par1.cpContactBufferHeader, par2.i, *par3.cpContactBufferHeader) As "?cpContactBufferHeaderInit@@YAPAUcpContactBufferHeader@@PAU1@I0@Z"
 cpSpaceAllocContactBuffer.i(*par1.cpSpace) As "?cpSpaceAllocContactBuffer@@YAPAUcpContactBufferHeader@@PAUcpSpace@@@Z"
 cpDampedRotarySpringAlloc.i() As "?cpDampedRotarySpringAlloc@@YAPAUcpDampedRotarySpring@@XZ"
 cpDampedRotarySpringInit.i(*par1.cpDampedRotarySpring, *par2.cpBody, *par3.cpBody, par4.d, par5.d, par6.d) As "?cpDampedRotarySpringInit@@YAPAUcpDampedRotarySpring@@PAU1@PAUcpBody@@1NNN@Z"
 cpDampedSpringAlloc.i() As "?cpDampedSpringAlloc@@YAPAUcpDampedSpring@@XZ"
 cpDampedSpringInit.i(*par1.cpDampedSpring, *par2.cpBody, *par3.cpBody, *par4.cpVect, *par5.cpVect, par6.d, par7.d, par8.d) As "?cpDampedSpringInit_@@YAPAUcpDampedSpring@@PAU1@PAUcpBody@@1AAUcpVect@@2NNN@Z"
 cpGearJointAlloc.i() As "?cpGearJointAlloc@@YAPAUcpGearJoint@@XZ"
 cpGearJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, par4.d, par5.d) As "?cpGearJointInit@@YAPAUcpGearJoint@@PAU1@PAUcpBody@@1NN@Z"
 cpGrooveJointAlloc.i() As "?cpGrooveJointAlloc@@YAPAUcpGrooveJoint@@XZ"
 cpGrooveJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, *par4.cpVect, *par5.cpVect, *par6.cpVect) As "?cpGrooveJointInit_@@YAPAUcpGrooveJoint@@PAU1@PAUcpBody@@1AAUcpVect@@22@Z"
 cpHandleInit.i(*par1.cpHandle, par2.i) As "?cpHandleInit@@YAPAUcpHandle@@PAU1@PAX@Z"
 cpHashSetAlloc.i() As "?cpHashSetAlloc@@YAPAUcpHashSet@@XZ"
 cpHashSetInit.i(*par1.cpHashSet, par2.i, *func3, par4.i, *func5, par6.i) As "?cpHashSetInit@@YAPAUcpHashSet@@PAU1@HP6AHPAX1@ZP6APAX11@Z@Z"
 cpHashSetNew.i(par1.i, *func2, par3.i, *func4, par5.i) As "?cpHashSetNew@@YAPAUcpHashSet@@HP6AHPAX0@ZP6APAX00@Z@Z"
 cpPinJointAlloc.i() As "?cpPinJointAlloc@@YAPAUcpPinJoint@@XZ"
 cpPinJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, *par4.cpVect, *par5.cpVect) As "?cpPinJointInit_@@YAPAUcpPinJoint@@PAU1@PAUcpBody@@1AAUcpVect@@2@Z"
 cpPivotJointAlloc.i() As "?cpPivotJointAlloc@@YAPAUcpPivotJoint@@XZ"
 cpPivotJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, *par4.cpVect, *par5.cpVect) As "?cpPivotJointInit_@@YAPAUcpPivotJoint@@PAU1@PAUcpBody@@1AAUcpVect@@2@Z"
 cpBoxShapeInit.i(*par1.cpPolyShape, *par2.cpBody, par3.d, par4.d) As "?cpBoxShapeInit@@YAPAUcpPolyShape@@PAU1@PAUcpBody@@NN@Z"
 cpPolyShapeAlloc.i() As "?cpPolyShapeAlloc@@YAPAUcpPolyShape@@XZ"
 cpPolyShapeInit.i(*par1.cpPolyShape, *par2.cpBody, par3.i, *par4.cpVect, *par5.cpVect) As "?cpPolyShapeInit_@@YAPAUcpPolyShape@@PAU1@PAUcpBody@@HPAUcpVect@@AAU3@@Z"
 cpRatchetJointAlloc.i() As "?cpRatchetJointAlloc@@YAPAUcpRatchetJoint@@XZ"
 cpRatchetJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, par4.d, par5.d) As "?cpRatchetJointInit@@YAPAUcpRatchetJoint@@PAU1@PAUcpBody@@1NN@Z"
 cpRotaryLimitJointAlloc.i() As "?cpRotaryLimitJointAlloc@@YAPAUcpRotaryLimitJoint@@XZ"
 cpRotaryLimitJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, par4.d, par5.d) As "?cpRotaryLimitJointInit@@YAPAUcpRotaryLimitJoint@@PAU1@PAUcpBody@@1NN@Z"
 cpSegmentShapeAlloc.i() As "?cpSegmentShapeAlloc@@YAPAUcpSegmentShape@@XZ"
 cpSegmentShapeInit.i(*par1.cpSegmentShape, *par2.cpBody, *par3.cpVect, *par4.cpVect, par5.d) As "?cpSegmentShapeInit_@@YAPAUcpSegmentShape@@PAU1@PAUcpBody@@AAUcpVect@@2N@Z"
 cpBoxShapeNew.i(*par1.cpBody, par2.d, par3.d) As "?cpBoxShapeNew@@YAPAUcpShape@@PAUcpBody@@NN@Z"
 cpCircleShapeNew.i(*par1.cpBody, par2.d, *par3.cpVect) As "?cpCircleShapeNew_@@YAPAUcpShape@@PAUcpBody@@NAAUcpVect@@@Z"
 cpPolyShapeNew.i(*par1.cpBody, par2.i, *par3.cpVect, *par4.cpVect) As "?cpPolyShapeNew_@@YAPAUcpShape@@PAUcpBody@@HPAUcpVect@@AAU3@@Z"
 cpSegmentShapeNew.i(*par1.cpBody, *par2.cpVect, *par3.cpVect, par4.d) As "?cpSegmentShapeNew_@@YAPAUcpShape@@PAUcpBody@@AAUcpVect@@1N@Z"
 cpShapeInit.i(*par1.cpShape, *par2.cpShapeClass, *par3.cpBody) As "?cpShapeInit@@YAPAUcpShape@@PAU1@PBUcpShapeClass@@PAUcpBody@@@Z"
 cpSpaceAddShape.i(*par1.cpSpace, *par2.cpShape) As "?cpSpaceAddShape@@YAPAUcpShape@@PAUcpSpace@@PAU1@@Z"
 cpSpaceAddStaticShape.i(*par1.cpSpace, *par2.cpShape) As "?cpSpaceAddStaticShape@@YAPAUcpShape@@PAUcpSpace@@PAU1@@Z"
 cpSpaceSegmentQueryFirst.i(*par1.cpSpace, *par2.cpVect, *par3.cpVect, par4.i, par5.i, *par6.cpSegmentQueryInfo) As "?cpSpaceSegmentQueryFirst_@@YAPAUcpShape@@PAUcpSpace@@AAUcpVect@@1AAI2PAUcpSegmentQueryInfo@@@Z"
 cpSimpleMotorAlloc.i() As "?cpSimpleMotorAlloc@@YAPAUcpSimpleMotor@@XZ"
 cpSimpleMotorInit.i(*par1.cpSimpleMotor, *par2.cpBody, *par3.cpBody, par4.d) As "?cpSimpleMotorInit@@YAPAUcpSimpleMotor@@PAU1@PAUcpBody@@1N@Z"
 cpSlideJointAlloc.i() As "?cpSlideJointAlloc@@YAPAUcpSlideJoint@@XZ"
 cpSlideJointInit.i(par1.i, *par2.cpBody, *par3.cpBody, *par4.cpVect, *par5.cpVect, par6.d, par7.d) As "?cpSlideJointInit_@@YAPAUcpSlideJoint@@PAU1@PAUcpBody@@1AAUcpVect@@2NN@Z"
 cpSpaceAlloc.i() As "?cpSpaceAlloc@@YAPAUcpSpace@@XZ"
 cpSpaceInit.i(*par1.cpSpace) As "?cpSpaceInit@@YAPAUcpSpace@@PAU1@@Z"
 cpSpaceNew.i() As "?cpSpaceNew@@YAPAUcpSpace@@XZ"
 cpSpaceHashAlloc.i() As "?cpSpaceHashAlloc@@YAPAUcpSpaceHash@@XZ"
 cpSpaceHashInit.i(*par1.cpSpaceHash, par2.d, par3.i, *func4) As "?cpSpaceHashInit@@YAPAUcpSpaceHash@@PAU1@NHP6A?AUcpBB@@PAX@Z@Z"
 cpSpaceHashNew.i(par1.d, par2.i, *func3) As "?cpSpaceHashNew@@YAPAUcpSpaceHash@@NHP6A?AUcpBB@@PAX@Z@Z"
 cpArrayPop(*par1.cpArray) As "?cpArrayPop@@YAPAXPAUcpArray@@@Z"
 cpHashSetFind(*par1.cpHashSet, par2.i, par3.i) As "?cpHashSetFind@@YAPAXPAUcpHashSet@@IPAX@Z"
 cpHashSetInsert(*par1.cpHashSet, par2.i, par3.i, par4.i) As "?cpHashSetInsert@@YAPAXPAUcpHashSet@@IPAX1@Z"
 cpHashSetRemove(*par1.cpHashSet, par2.i, par3.i) As "?cpHashSetRemove@@YAPAXPAUcpHashSet@@IPAX@Z"
 cpSpaceGetPostStepData(*par1.cpSpace, par2.i) As "?cpSpaceGetPostStepData@@YAPAXPAUcpSpace@@PAX@Z"
 cpApplyDampedSpring(*par1.cpBody, *par2.cpBody, *par3.cpVect, *par4.cpVect, par5.d, par6.d, par7.d, par8.d) As "?cpApplyDampedSpring_@@YAXPAUcpBody@@0AAUcpVect@@1NNNN@Z"
 cpArbiterApplyCachedImpulse(*par1.cpArbiter) As "?cpArbiterApplyCachedImpulse@@YAXPAUcpArbiter@@@Z"
 cpArbiterApplyImpulse(*par1.cpArbiter, par2.d) As "?cpArbiterApplyImpulse@@YAXPAUcpArbiter@@N@Z"
 cpArbiterDestroy(*par1.cpArbiter) As "?cpArbiterDestroy@@YAXPAUcpArbiter@@@Z"
 cpArbiterFree(*par1.cpArbiter) As "?cpArbiterFree@@YAXPAUcpArbiter@@@Z"
 cpArbiterGetNormal(*par1.cpVect, *par2.cpArbiter, par3.i) As "?cpArbiterGetNormal@@YAXAAUcpVect@@PBUcpArbiter@@H@Z"
 cpArbiterGetPoint(*par1.cpVect, *par2.cpArbiter, par3.i) As "?cpArbiterGetPoint@@YAXAAUcpVect@@PBUcpArbiter@@H@Z"
 cpArbiterIgnore(*par1.cpArbiter) As "?cpArbiterIgnore@@YAXPAUcpArbiter@@@Z"
 cpArbiterPreStep(*par1.cpArbiter, par2.d) As "?cpArbiterPreStep@@YAXPAUcpArbiter@@N@Z"
 cpArbiterTotalImpulse(*par1.cpVect, *par2.cpArbiter) As "?cpArbiterTotalImpulse@@YAXAAUcpVect@@PAUcpArbiter@@@Z"
 cpArbiterTotalImpulseWithFriction(*par1.cpVect, *par2.cpArbiter) As "?cpArbiterTotalImpulseWithFriction@@YAXAAUcpVect@@PAUcpArbiter@@@Z"
 cpArbiterUpdate(*par1.cpArbiter, *par2.cpContact, par3.i, *par4.cpCollisionHandler, *par5.cpShape, *par6.cpShape) As "?cpArbiterUpdate@@YAXPAUcpArbiter@@PAUcpContact@@HPAUcpCollisionHandler@@PAUcpShape@@3@Z"
 cpArrayAppend(*par1.cpArray, *par2.cpArray) As "?cpArrayAppend@@YAXPAUcpArray@@0@Z"
 cpArrayDeleteIndex(*par1.cpArray, par2.i) As "?cpArrayDeleteIndex@@YAXPAUcpArray@@H@Z"
 cpArrayDeleteObj(*par1.cpArray, par2.i) As "?cpArrayDeleteObj@@YAXPAUcpArray@@PAX@Z"
 cpArrayDestroy(*par1.cpArray) As "?cpArrayDestroy@@YAXPAUcpArray@@@Z"
 cpArrayEach(*par1.cpArray, *func2.i, *par3.i) As "?cpArrayEach@@YAXPAUcpArray@@P6AXPAX1@Z1@Z"
 cpArrayFree(*par1.cpArray) As "?cpArrayFree@@YAXPAUcpArray@@@Z"
 cpArrayPush(*par1.cpArray, par2.i) As "?cpArrayPush@@YAXPAUcpArray@@PAX@Z"
 cpBBClampVect(*par1.cpVect, *par2.cpBB, *par3.cpVect) As "?cpBBClampVect_@@YAXAAUcpVect@@AAUcpBB@@0@Z"
 cpBBNew(*par1.cpBB, par2.d, par3.d, par4.d, par5.d) As "?cpBBNew@@YAXAAUcpBB@@NNNN@Z"
 cpBBWrapVect(*par1.cpVect, *par2.cpBB, *par3.cpVect) As "?cpBBWrapVect@@YAXAAUcpVect@@AAUcpBB@@0@Z"
 cpBBexpand(*par1.cpBB, *par2.cpBB, *par3.cpVect) As "?cpBBexpand@@YAXAAUcpBB@@0AAUcpVect@@@Z"
 cpBBmerge(*par1.cpBB, *par2.cpBB, *par3.cpBB) As "?cpBBmerge@@YAXAAUcpBB@@00@Z"
 cpBodyActivate(*par1.cpBody) As "?cpBodyActivate@@YAXPAUcpBody@@@Z"
 cpBodyAddShape(*par1.cpBody, *par2.cpShape) As "?cpBodyAddShape@@YAXPAUcpBody@@PAUcpShape@@@Z"
 cpBodyApplyForce(*par1.cpBody, *par2.cpVect, *par3.cpVect) As "?cpBodyApplyForce_@@YAXAAPAUcpBody@@AAUcpVect@@1@Z"
 cpBodyApplyImpulse(*par1.cpBody, *par2.cpVect, *par3.cpVect) As "?cpBodyApplyImpulse_@@YAXPAUcpBody@@AAUcpVect@@1@Z"
 cpBodyDestroy(*par1.cpBody) As "?cpBodyDestroy@@YAXPAUcpBody@@@Z"
 cpBodyFree(*par1.cpBody) As "?cpBodyFree@@YAXPAUcpBody@@@Z"
 cpBodyLocal2World(*par1.cpVect, *par2.cpBody, *par3.cpVect) As "?cpBodyLocal2World@@YAXAAUcpVect@@PBUcpBody@@0@Z"
 cpBodyRemoveShape(*par1.cpBody, *par2.cpShape) As "?cpBodyRemoveShape@@YAXPAUcpBody@@PAUcpShape@@@Z"
 cpBodyResetForces(*par1.cpBody) As "?cpBodyResetForces@@YAXPAUcpBody@@@Z"
 cpBodySetAngle(*par1.cpBody, par2.d) As "?cpBodySetAngle@@YAXPAUcpBody@@N@Z"
 cpBodySetMass(*par1.cpBody, par2.d) As "?cpBodySetMass@@YAXPAUcpBody@@N@Z"
 cpBodySetMoment(*par1.cpBody, par2.d) As "?cpBodySetMoment@@YAXPAUcpBody@@N@Z"
 cpBodySleep(*par1.cpBody) As "?cpBodySleep@@YAXPAUcpBody@@@Z"
 cpBodySleepWithGroup(*par1.cpBody, *par2.cpBody) As "?cpBodySleepWithGroup@@YAXPAUcpBody@@0@Z"
 cpBodySlew(*par1.cpBody, *par2.cpVect, par3.d) As "?cpBodySlew_@@YAXPAUcpBody@@AAUcpVect@@N@Z"
 cpBodyUpdatePosition(*par1.cpBody, par2.d) As "?cpBodyUpdatePosition@@YAXPAUcpBody@@N@Z"
 cpBodyUpdateVelocity(*par1.cpBody, *par2.cpVect, par3.d, par4.d) As "?cpBodyUpdateVelocity_@@YAXPAUcpBody@@AAUcpVect@@NN@Z"
 cpBodyWorld2Local(*par1.cpVect, *par2.cpBody, *par3.cpVect) As "?cpBodyWorld2Local@@YAXAAUcpVect@@PBUcpBody@@0@Z"
 cpCentroidForPoly(*par1.cpVect, par2.i, *par3.cpVect) As "?cpCentroidForPoly@@YAXAAUcpVect@@HPBU1@@Z"
 cpCircleShapeCacheData(*par1.cpBB, *par2.cpShape, *par3.cpVect, *par4.cpVect) As "?cpCircleShapeCacheData@@YAXAAUcpBB@@PAUcpShape@@AAUcpVect@@2@Z"
 cpCircleShapeSegmentQuery(*par1.cpShape, *par2.cpVect, *par3.cpVect, *par4.cpSegmentQueryInfo) As "?cpCircleShapeSegmentQuery_@@YAXPAUcpShape@@AAUcpVect@@1PAUcpSegmentQueryInfo@@@Z"
 cpCircleShapeSetOffset(*par1.cpShape, *par2.cpVect) As "?cpCircleShapeSetOffset_@@YAXPAUcpShape@@AAUcpVect@@@Z"
 cpCircleShapeSetRadius(*par1.cpShape, par2.d) As "?cpCircleShapeSetRadius@@YAXPAUcpShape@@N@Z"
 cpConstraintActivateBodies(par1.i) As "?cpConstraintActivateBodies@@YAXPAUcpConstraint@@@Z"
 cpConstraintDestroy(par1.i) As "?cpConstraintDestroy@@YAXPAUcpConstraint@@@Z"
 cpConstraintFree(par1.i) As "?cpConstraintFree@@YAXPAUcpConstraint@@@Z"
 cpConstraintInit(par1.i, par2.i, *par3.cpBody, *par4.cpBody) As "?cpConstraintInit@@YAXPAUcpConstraint@@PBUcpConstraintClass@@PAUcpBody@@2@Z"
 cpGearJointSetRatio(par1.i, par2.d) As "?cpGearJointSetRatio@@YAXPAUcpConstraint@@N@Z"
 cpGrooveJointSetGrooveA(par1.i, *par2.cpVect) As "?cpGrooveJointSetGrooveA_@@YAXPAUcpConstraint@@AAUcpVect@@@Z"
 cpGrooveJointSetGrooveB(par1.i, *par2.cpVect) As "?cpGrooveJointSetGrooveB_@@YAXPAUcpConstraint@@AAUcpVect@@@Z"
 cpHandleRelease(*par1.cpHandle, *par2.cpArray) As "?cpHandleRelease@@YAXPAUcpHandle@@PAUcpArray@@@Z"
 cpHandleRetain(*par1.cpHandle) As "?cpHandleRetain@@YAXPAUcpHandle@@@Z"
 cpHashSetDestroy(*par1.cpHashSet) As "?cpHashSetDestroy@@YAXPAUcpHashSet@@@Z"
 cpHashSetEach(*par1.cpHashSet, *func2, par3.i, par4.i) As "?cpHashSetEach@@YAXPAUcpHashSet@@P6AXPAX1@Z1@Z"
 cpHashSetFilter(*par1.cpHashSet, *func2, par3.i, par4.i) As "?cpHashSetFilter@@YAXPAUcpHashSet@@P6AHPAX1@Z1@Z"
 cpHashSetFree(*par1.cpHashSet) As "?cpHashSetFree@@YAXPAUcpHashSet@@@Z"
 cpHashSetResize(*par1.cpHashSet) As "?cpHashSetResize@@YAXPAUcpHashSet@@@Z"
 cpInitChipmunk() As "?cpInitChipmunk@@YAXXZ"
 cpInitCollisionFuncs() As "?cpInitCollisionFuncs@@YAXXZ"
 cpMessage(*par1.c, *par2.c, *par3.c, par4.i, par5.i) As "?cpMessage@@YAXPBD00HH@Z"
 cpPolyShapeCacheData(*par1.cpBB, *par2.cpShape, *par3.cpVect, *par4.cpVect) As "?cpPolyShapeCacheData_@@YAXAAUcpBB@@PAUcpShape@@AAUcpVect@@2@Z"
 cpPolyShapeDestroy(*par1.cpShape) As "?cpPolyShapeDestroy@@YAXPAUcpShape@@@Z"
 cpPolyShapeGetVert(*par1.cpVect, *par2.cpShape, par3.i) As "?cpPolyShapeGetVert@@YAXAAUcpVect@@PAUcpShape@@H@Z"
 cpPolyShapeSegmentQuery(*par1.cpShape, *par2.cpVect, *par3.cpVect, *par4.cpSegmentQueryInfo) As "?cpPolyShapeSegmentQuery_@@YAXPAUcpShape@@AAUcpVect@@1PAUcpSegmentQueryInfo@@@Z"
 cpPolyShapeSetVerts(*par1.cpShape, par2.i, *par3.cpVect, *par4.cpVect) As "?cpPolyShapeSetVerts_@@YAXPAUcpShape@@HPAUcpVect@@AAU2@@Z"
 cpPolyShapeTransformAxes(*par1.cpPolyShape, *par2.cpVect, *par3.cpVect) As "?cpPolyShapeTransformAxes_@@YAXPAUcpPolyShape@@AAUcpVect@@1@Z"
 cpPolyShapeTransformVerts(*par1.cpPolyShape, *par2.cpVect, *par3.cpVect) As "?cpPolyShapeTransformVerts_@@YAXPAUcpPolyShape@@AAUcpVect@@1@Z"
 cpRecenterPoly(par1.i, *par2.cpVect) As "?cpRecenterPoly@@YAXHPAUcpVect@@@Z"
 cpResetShapeIdCounter() As "?cpResetShapeIdCounter@@YAXXZ"
 cpSegmentQueryHitPoint(*par1.cpVect, *par2.cpVect, *par3.cpVect, *par4.cpSegmentQueryInfo) As "?cpSegmentQueryHitPoint@@YAXAAUcpVect@@00AAUcpSegmentQueryInfo@@@Z"
 cpSegmentQueryInfoPrint(*par1.cpSegmentQueryInfo) As "?cpSegmentQueryInfoPrint@@YAXPAUcpSegmentQueryInfo@@@Z"
 cpSegmentShapeCacheData(*par1.cpBB, *par2.cpShape, *par3.cpVect, *par4.cpVect) As "?cpSegmentShapeCacheData@@YAXAAUcpBB@@PAUcpShape@@AAUcpVect@@2@Z"
 cpSegmentShapeGetA(*par1.cpVect, *par2.cpShape) As "?cpSegmentShapeGetA@@YAXAAUcpVect@@PAUcpShape@@@Z"
 cpSegmentShapeGetB(*par1.cpVect, *par2.cpShape) As "?cpSegmentShapeGetB@@YAXAAUcpVect@@PAUcpShape@@@Z"
 cpSegmentShapeGetNormal(*par1.cpVect, *par2.cpShape) As "?cpSegmentShapeGetNormal@@YAXAAUcpVect@@PAUcpShape@@@Z"
 cpSegmentShapeSegmentQuery(*par1.cpShape, *par2.cpVect, *par3.cpVect, *par4.cpSegmentQueryInfo) As "?cpSegmentShapeSegmentQuery_@@YAXPAUcpShape@@AAUcpVect@@1PAUcpSegmentQueryInfo@@@Z"
 cpSegmentShapeSetEndpoints(*par1.cpShape, *par2.cpVect, *par3.cpVect) As "?cpSegmentShapeSetEndpoints_@@YAXPAUcpShape@@AAUcpVect@@1@Z"
 cpSegmentShapeSetRadius(*par1.cpShape, par2.d) As "?cpSegmentShapeSetRadius@@YAXPAUcpShape@@N@Z"
 cpShapeCacheBB(*par1.cpBB, *par2.cpShape) As "?cpShapeCacheBB@@YAXAAUcpBB@@PAUcpShape@@@Z"
 cpShapeDestroy(*par1.cpShape) As "?cpShapeDestroy@@YAXPAUcpShape@@@Z"
 cpShapeFree(*par1.cpShape) As "?cpShapeFree@@YAXPAUcpShape@@@Z"
 cpSpaceActivateBody(*par1.cpSpace, *par2.cpBody) As "?cpSpaceActivateBody@@YAXPAUcpSpace@@PAUcpBody@@@Z"
 cpSpaceActivateShapesTouchingShape(*par1.cpSpace, *par2.cpShape) As "?cpSpaceActivateShapesTouchingShape@@YAXPAUcpSpace@@PAUcpShape@@@Z"
 cpSpaceAddCollisionHandler(*par1.cpSpace, par2.i, par3.i, *func4, *par5.cpSpace, par6.i, *func7, *par8.cpSpace, par9.i, *func10, *par11.cpSpace, par12.i, *func13, *par14.cpSpace, par15.i, par16.i) As "?cpSpaceAddCollisionHandler@@YAXPAUcpSpace@@IIP6AHPAUcpArbiter@@0PAX@Z3P6AX102@Z42@Z"
 cpSpaceAddPostStepCallback(*par1.cpSpace, *func2, par3.i, par4.i, par5.i, par6.i) As "?cpSpaceAddPostStepCallback@@YAXPAUcpSpace@@P6AX0PAX1@Z11@Z"
 cpSpaceBBQuery(*par1.cpSpace, *par2.cpBB, par3.i, par4.i, *func5, par6.i, par7.i) As "?cpSpaceBBQuery_@@YAXPAUcpSpace@@AAUcpBB@@AAI2P6AXPAUcpShape@@PAX@Z4@Z"
 cpSpaceDestroy(*par1.cpSpace) As "?cpSpaceDestroy@@YAXPAUcpSpace@@@Z"
 cpSpaceEachBody(*par1.cpSpace, *func2, par3.i, par4.i) As "?cpSpaceEachBody@@YAXPAUcpSpace@@P6AXPAUcpBody@@PAX@Z2@Z"
 cpSpaceFree(*par1.cpSpace) As "?cpSpaceFree@@YAXPAUcpSpace@@@Z"
 cpSpaceFreeChildren(*par1.cpSpace) As "?cpSpaceFreeChildren@@YAXPAUcpSpace@@@Z"
 cpSpaceHashAllocTable(*par1.cpSpaceHash, par2.i) As "?cpSpaceHashAllocTable@@YAXPAUcpSpaceHash@@H@Z"
 cpSpaceHashDestroy(*par1.cpSpaceHash) As "?cpSpaceHashDestroy@@YAXPAUcpSpaceHash@@@Z"
 cpSpaceHashEach(*par1.cpSpaceHash, *func2.i, *par3.i) As "?cpSpaceHashEach@@YAXPAUcpSpaceHash@@P6AXPAX1@Z1@Z"
 cpSpaceHashFree(*par1.cpSpaceHash) As "?cpSpaceHashFree@@YAXPAUcpSpaceHash@@@Z"
 cpSpaceHashInsert(*par1.cpSpaceHash, par2.i, par3.i, *par4.cpBB) As "?cpSpaceHashInsert_@@YAXPAUcpSpaceHash@@PAXIAAUcpBB@@@Z"
 cpSpaceHashQueryRehash(*par1.cpSpaceHash, *func2, par3.i, par4.i, par5.i) As "?cpSpaceHashQueryRehash@@YAXPAUcpSpaceHash@@P6AXPAX11@Z1@Z"
 cpSpaceHashQuery(*par1.cpSpaceHash, par2.i, *par3.cpBB, *func4, par5.i, par6.i, par7.i) As "?cpSpaceHashQuery_@@YAXPAUcpSpaceHash@@PAXAAUcpBB@@P6AX111@Z1@Z"
 cpSpaceHashRehash(*par1.cpSpaceHash) As "?cpSpaceHashRehash@@YAXPAUcpSpaceHash@@@Z"
 cpSpaceHashRehashObject(*par1.cpSpaceHash, par2.i, par3.i) As "?cpSpaceHashRehashObject@@YAXPAUcpSpaceHash@@PAXI@Z"
 cpSpaceHashRemove(*par1.cpSpaceHash, par2.i, par3.i) As "?cpSpaceHashRemove@@YAXPAUcpSpaceHash@@PAXI@Z"
 cpSpaceHashResize(*par1.cpSpaceHash, par2.d, par3.i) As "?cpSpaceHashResize@@YAXPAUcpSpaceHash@@NH@Z"
 cpSpaceHashSegmentQuery(*par1.cpSpaceHash, par2.i, *par3.cpVect, *par4.cpVect, par5.d, *func6, par7.i, par8.i, par9.i) As "?cpSpaceHashSegmentQuery_@@YAXPAUcpSpaceHash@@PAXAAUcpVect@@2NP6AN111@Z1@Z"
 cpSpaceLock(*par1.cpSpace) As "?cpSpaceLock@@YAXPAUcpSpace@@@Z"
 cpSpacePointQuery(*par1.cpSpace, *par2.cpVect, par3.i, par4.i, *func5, par6.i, par7.i) As "?cpSpacePointQuery_@@YAXPAUcpSpace@@AAUcpVect@@AAI2P6AXPAUcpShape@@PAX@Z4@Z"
 cpSpacePopContacts(*par1.cpSpace, par2.i) As "?cpSpacePopContacts@@YAXPAUcpSpace@@H@Z"
 cpSpaceProcessComponents(*par1.cpSpace, par2.d) As "?cpSpaceProcessComponents@@YAXPAUcpSpace@@N@Z"
 cpSpacePushContacts(*par1.cpSpace, par2.i) As "?cpSpacePushContacts@@YAXPAUcpSpace@@H@Z"
 cpSpacePushFreshContactBuffer(*par1.cpSpace) As "?cpSpacePushFreshContactBuffer@@YAXPAUcpSpace@@@Z"
 cpSpaceRehashShape(*par1.cpSpace, *par2.cpShape) As "?cpSpaceRehashShape@@YAXPAUcpSpace@@PAUcpShape@@@Z"
 cpSpaceRehashStatic(*par1.cpSpace) As "?cpSpaceRehashStatic@@YAXPAUcpSpace@@@Z"
 cpSpaceRemoveBody(*par1.cpSpace, *par2.cpBody) As "?cpSpaceRemoveBody@@YAXPAUcpSpace@@PAUcpBody@@@Z"
 cpSpaceRemoveCollisionHandler(*par1.cpSpace, par2.i, par3.i) As "?cpSpaceRemoveCollisionHandler@@YAXPAUcpSpace@@II@Z"
 cpSpaceRemoveConstraint(*par1.cpSpace, par2.i) As "?cpSpaceRemoveConstraint@@YAXPAUcpSpace@@PAUcpConstraint@@@Z"
 cpSpaceRemoveShape(*par1.cpSpace, *par2.cpShape) As "?cpSpaceRemoveShape@@YAXPAUcpSpace@@PAUcpShape@@@Z"
 cpSpaceRemoveStaticShape(*par1.cpSpace, *par2.cpShape) As "?cpSpaceRemoveStaticShape@@YAXPAUcpSpace@@PAUcpShape@@@Z"
 cpSpaceResizeActiveHash(*par1.cpSpace, par2.d, par3.i) As "?cpSpaceResizeActiveHash@@YAXPAUcpSpace@@NH@Z"
 cpSpaceResizeStaticHash(*par1.cpSpace, par2.d, par3.i) As "?cpSpaceResizeStaticHash@@YAXPAUcpSpace@@NH@Z"
 cpSpaceSetDefaultCollisionHandler(*par1.cpSpace, *func2, *par3.cpSpace, par4.i, *func5, *par6.cpSpace, par7.i, *func8, *par9.cpSpace, par10.i, *func11, *par12.cpSpace, par13.i, par14.i) As "?cpSpaceSetDefaultCollisionHandler@@YAXPAUcpSpace@@P6AHPAUcpArbiter@@0PAX@Z3P6AX102@Z42@Z"
 cpSpaceStep(*par1.cpSpace, par2.d) As "?cpSpaceStep@@YAXPAUcpSpace@@N@Z"
 cpSpaceUnlock(*par1.cpSpace) As "?cpSpaceUnlock@@YAXPAUcpSpace@@@Z"
 cpv(*par1.cpVect, par2.d, par3.d) As "?cpv@@YAXAAUcpVect@@NN@Z"
 cpvadd(*par1.cpVect, *par2.cpVect, *par3.cpVect) As "?cpvadd@@YAXAAUcpVect@@00@Z"
 cpvclamp(*par1.cpVect, *par2.cpVect, par3.d) As "?cpvclamp@@YAXAAUcpVect@@0N@Z"
 cpvforangle(*par1.cpVect, par2.d) As "?cpvforangle@@YAXAAUcpVect@@N@Z"
 cpvlerp(*par1.cpVect, *par2.cpVect, *par3.cpVect, par4.d) As "?cpvlerp@@YAXAAUcpVect@@00N@Z"
 cpvlerpconst(*par1.cpVect, *par2.cpVect, *par3.cpVect, par4.d) As "?cpvlerpconst@@YAXAAUcpVect@@00N@Z"
 cpvmult(*par1.cpVect, *par2.cpVect, par3.d) As "?cpvmult@@YAXAAUcpVect@@0N@Z"
 cpvneg(*par1.cpVect, *par2.cpVect) As "?cpvneg@@YAXAAUcpVect@@0@Z"
 cpvnormalize(*par1.cpVect, *par2.cpVect) As "?cpvnormalize@@YAXAAUcpVect@@0@Z"
 cpvnormalize_safe(*par1.cpVect, *par2.cpVect) As "?cpvnormalize_safe@@YAXAAUcpVect@@0@Z"
 cpvperp(*par1.cpVect, *par2.cpVect) As "?cpvperp@@YAXAAUcpVect@@0@Z"
 cpvproject(*par1.cpVect, *par2.cpVect, *par3.cpVect) As "?cpvproject@@YAXAAUcpVect@@00@Z"
 cpvrotate(*par1.cpVect, *par2.cpVect, *par3.cpVect) As "?cpvrotate@@YAXAAUcpVect@@00@Z"
 cpvrperp(*par1.cpVect, *par2.cpVect) As "?cpvrperp@@YAXAAUcpVect@@0@Z"
 cpvslerp(*par1.cpVect, *par2.cpVect, *par3.cpVect, par4.d) As "?cpvslerp@@YAXAAUcpVect@@00N@Z"
 cpvslerpconst(*par1.cpVect, *par2.cpVect, *par3.cpVect, par4.d) As "?cpvslerpconst@@YAXAAUcpVect@@00N@Z"
 cpvsub(*par1.cpVect, *par2.cpVect, *par3.cpVect) As "?cpvsub@@YAXAAUcpVect@@00@Z"
 cpvunrotate(*par1.cpVect, *par2.cpVect, *par3.cpVect) As "?cpvunrotate@@YAXAAUcpVect@@00@Z"
EndImport

; IDE Options = PureBasic 4.51 (Windows - x86)
; Folding = --
; EnableXP